# Needed for the tables in the simulation study in the paper "A Unifying Approach to the 
# Estimation of the Conditional Akaike Information in Generalized Linear Mixed Models".
# Exponential distribution with random intercept.
# author: B. Saefken

# This R code calculates the log-likelihoods for the datasets in \data.
# The tables with the results are written into the results folders.


loglik <- function(daten) {
  # Calculates the log-likelihood
  #
  # Args: daten = A data frame generated by the genData function in fcts.r
  #
  # Returns:	The log-likelihood of the data for an exponential model.
  #
	b <- try(gamm(y ~ x + s(groups, bs = "re"), 
                family     = Gamma(link = "log"),
                data       = daten, 
                scale      = 1, 
                verbosePQL = FALSE))
	if(class(b)[1] == "try-error"){
		cat("NA's produziert in loglik\n")
		return(NA)
	}	
	return(sum(dgamma(daten$y, shape = 1, scale = b$gam$fitted.values,
                log = TRUE)))
}

Simulation <- function(Slops, Intercepts, anzahlCluster, clusterGroesse, varianzRandomEffects){
  # The wrapper for the calculation of the log-likelihoods.
  #
  # Args: Slops = A vector of slops.
  #       Intercepts = a vector of intercepts.
  #       anzahlCluster = A vector of the number of clusters.
  #       clusterGroesse = A vector of cluster sizes.
  #       varianzRandomEffects = A vector of variances of the random effects.
  #
  # Returns:	Writes a table with the log-likelihoods into the \results folder.
  #
for(w in Slops){
	for(v in Intercepts){
		for(p in anzahlCluster){
			for(r in clusterGroesse){
				for(s in varianzRandomEffects){					
				cat("Start of loop: Slope: ", w, 
            "; Intercept: ", v, 
            "; Anzahl Cluster: ", p, 
            "; Cluster Groesse: ", r, 
            "; tau^2: ", s, 
            "\n", sep = "")
				loadString <- paste("data/NC_", p, 
                            "_CG_", r,
                            "_t2_", s, 
                            "_b0_", v, 
                            "_b1_", w, 
                            ".Rdata", sep = "")
				load(file = loadString)

        ll <- numeric(liste$NoSets)
        for(i in 1:liste$NoSets) {
          ll[i] <- loglik(liste[[6 + i]])
        }
        
				if(file.exists("results") == FALSE) {
				dir.create("results")	
				}
				tableString <- paste("results/", p, r,
                             "/loglik_Tabelle_NoCluster_", p, 
                             "_NoSize_", r, 
                             "_sigma2_", s, 
                             "_Int_", v, 
                             "_Slope_", w, 
                             ".txt", sep = "")			
      write.table(data.frame(ll),
                  file      = tableString, 
                  quote     = FALSE, 
                  row.names = FALSE)
				}
			}
		}
	}
}
}

require("mgcv")
require("nlme")
require("splines")

beta0            <- .1
beta1            <- .2
NumberOfClusters <- c(5, 10)
SizeOfClusters   <- c(5, 10)
tau2             <- (14:18)/10


Simulation(Slops                = beta1, 
           Intercepts           = beta0, 
           anzahlCluster        = NumberOfClusters, 
           clusterGroesse       = SizeOfClusters,
           varianzRandomEffects = tau2)
