# Generates the tables for the simulation study in the paper "A Unifying Approach to the 
# Estimation of the Conditional Akaike Information in Generalized Linear Mixed Models"
# Exponential distribution with random intercept.
# author: B. Saefken

# This code generates the ptables in the simulation study. The results need to be
# saved as .txt in the \results folder(s). This includes the log-likelihoods!

# Table is return as xtable
require("xtable")

# The variance of the random effects
a <- c(0, .5, 1)
# The cluster sizes
b <- c(5, 10)
# The number of clusters
d <- c(5, 10)
# A threshold that excludes numerical failures in the Yu & Yau implementation.
threshold <- 200

asd <- data.frame(m       = rep(b, each = 6),
                  n       = rep(rep(d, each = 3),  2),
                  d       = rep(a, 4), 
                  analyBC = 1:12, 
                  asympBC = 1:12, 
                  yuyauBC = 1:12, 
                  donBC   = 1:12, 
                  analySd = 1:12, 
                  asympSd = 1:12, 
                  yuyauSd = 1:12, 
                  donSd   = 1:12)
                  
l <- 1

for(m in d) {
  for(i in b) {
  
G <- paste(m, i ,"/AIC_Tabelle_NoCluster_", m, 
           "_NoSize_", i, 
           "_sigma2_", a, 
           "_Int_0.1_Slope_0.2.txt",sep="")
H <- paste(m, i, "/loglik_Tabelle_NoCluster_", m, 
           "_NoSize_", i, 
           "_sigma2_", a, 
           "_Int_0.1_Slope_0.2.txt",sep="")
    
    for (j in 1:length(G)) {
      aics    <- read.table(G[j], header = TRUE)
      logliks <- read.table(H[j], header = TRUE)
      all     <- cbind(aics, logliks)
      all     <- na.omit(all)
      
      for(k in 1:7) {
        all[, k] <- (all[, k] + 2 * all[, 8]) / 2
      }
      
      asd$analyBC[l] <- mean(all$condAIC)
      asd$asympBC[l] <- mean(all$trueAIC)
      if (length(which(abs(all$yyAIC) > threshold)) > 0) {
        asd$yuyauBC[l] <- mean(all$yyAIC[- which(abs(all$yyAIC) > threshold)])
        asd$yuyauSd[l] <- sd(all$yyAIC[- which(abs(all$yyAIC) > threshold)])
      } else {
        asd$yuyauBC[l] <- mean(all$yyAIC)      
        asd$yuyauSd[l] <- sd(all$yyAIC)
      }
      asd$donBC[l]   <- mean(all$donAIC)
      asd$analySd[l] <- sd(all$condAIC)
      asd$asympSd[l] <- sd(all$trueAIC)
      
      asd$donSd[l]   <- sd(all$donAIC)
      
      l <- l + 1
      
    }
  }
}

xtable(asd)