# Starter for the simulation study in the paper "A Unifying Approach to the 
# Estimation of the Conditional Akaike Information in Generalized Linear Mixed Models"
# Exponential distribution with random intercept.
# author: B. Saefken

# In this file all input values are defined.
# The header file is loaded. It loads all the functions and packages that are 
# used in the simulation.
# This simulation study was designed to run on a linux cluster.

# How many cores in the parallized part are used
NumberOfCores <- 20
generate.data <- FALSE	
set.seed(7)

# Only specify if datasets are generated
NoOfDataSets <- 1000
beta0 <- .1
beta1 <- .2
SizeOfClusters <- c(5,10)
NumberOfClusters <- c(5,10)
varianzRandomEffects <- (0:18)/10

# Required packages are loaded
require("mgcv")
require("nlme")
require("doMC")
require("foreach")
registerDoMC(cores = NumberOfCores)

# Load functions
source("fcts.r")

# Datasets are generated
if (generate.data) {
generateDataSets(beta1,
                 beta0, 
                 NumberOfClusters, 
                 SizeOfClusters, 
                 varianzRandomEffects, 
                 NoOfDataSets)
}  

# The simulation is started
Simulation(beta1, 
           beta0, 
           NumberOfClusters, 
           SizeOfClusters, 
           varianzRandomEffects)