# Plotter for the simulation study in the paper "A Unifying Approach to the 
# Estimation of the Conditional Akaike Information in Generalized Linear Mixed Models"
# Poisson distribution with random intercept.
# author: B. Saefken

# This code generates the plots in the simulation study. The results need to be
# saved as .txt in the \results folder(s).

# Required packages
library("ggplot2")
# Variances of random effects
a <- c((0:8)/10)
# Which reference for the proposed AICs should be used.
same.reference <- FALSE

selectFrqt <- numeric(length(a))
selectFrqc <- numeric(length(a))
selectFrqm <- numeric(length(a))
selectFrqd <- numeric(length(a))
selectFrqy <- numeric(length(a))

if(same.reference) {
  r <- 7
} else {
  r <- 2
}

# Reads data and writes the frequencies (see paper) into a data frame

G <- paste("55/AIC_Tabelle_NoCluster_5_NoSize_5_sigma2_", a, 
           "_Int_0.1_Slope_0.2.txt", sep = "")

for (j in 1:length(G)){
	asd <- read.table(G[j], header = TRUE)
	analyAIC <- na.omit(asd[, c(r, 4)])
	margAIC  <- na.omit(asd[, c(7, 5)])
	donAIC   <- na.omit(asd[, c(7, 6)])
	yuyauAIC <- na.omit(asd[, c(7, 3)])
	selectFrqc[j] <- sum(analyAIC[2] < analyAIC[1])/length(analyAIC[1])
	selectFrqm[j] <- sum(margAIC[2]  < margAIC[1]) /length(margAIC[1])
	selectFrqd[j] <- sum(donAIC[2]   < donAIC[1])  /length(donAIC[1])
	selectFrqy[j] <- sum(yuyauAIC[2] < yuyauAIC[1])/length(yuyauAIC[1])
}

L <- c("Proposed cAIC", 
       "Marginal AIC", 
       "Donohue's cAIC", 
       "YuYau's AIC")
       
df55 <- data.frame(x        = rep(a, 4), 
                   val      = c(selectFrqc, 
                                selectFrqm, 
                                selectFrqd, 
                                selectFrqy), 
                   Variable = rep(L, each = length(a)), 
                   m        = 5, 
                   n_i      = 5)

 G <- paste("510/AIC_Tabelle_NoCluster_5_NoSize_10_sigma2_", a, 
            "_Int_0.1_Slope_0.2.txt", sep = "")


for (j in 1:length(G)){
	asd <- read.table(G[j], header = TRUE)
	analyAIC <- na.omit(asd[, c(r, 4)])
	margAIC  <- na.omit(asd[, c(7, 5)])
	donAIC   <- na.omit(asd[, c(7, 6)])
	yuyauAIC <- na.omit(asd[, c(7, 3)])
	selectFrqc[j] <- sum(analyAIC[2] < analyAIC[1])/length(analyAIC[1])
	selectFrqm[j] <- sum(margAIC[2]  < margAIC[1]) /length(margAIC[1])
	selectFrqd[j] <- sum(donAIC[2]   < donAIC[1])  /length(donAIC[1])
	selectFrqy[j] <- sum(yuyauAIC[2] < yuyauAIC[1])/length(yuyauAIC[1])
}

L <- c("Proposed cAIC", 
       "Marginal AIC",  
       "Donohue's cAIC", 
       "YuYau's AIC")
df510 <- data.frame(x        = rep(a, 4), 
                    val      = c(selectFrqc, 
                                 selectFrqm, 
                                 selectFrqd, 
                                 selectFrqy), 
                    Variable = rep(L, each = length(a)), 
                    m        = 5, 
                    n_i      = 10)
				   
G <- paste("105/AIC_Tabelle_NoCluster_10_NoSize_5_sigma2_", a, 
           "_Int_0.1_Slope_0.2.txt", sep = "")

for (j in 1:length(G)){
	asd <- read.table(G[j], header = TRUE)
	analyAIC <- na.omit(asd[, c(r, 4)])
	margAIC  <- na.omit(asd[, c(7, 5)])
	donAIC   <- na.omit(asd[, c(7, 6)])
	yuyauAIC <- na.omit(asd[, c(7, 3)])
	selectFrqc[j] <- sum(analyAIC[2] < analyAIC[1])/length(analyAIC[1])
	selectFrqm[j] <- sum(margAIC[2]  < margAIC[1]) /length(margAIC[1])
	selectFrqd[j] <- sum(donAIC[2]   < donAIC[1])  /length(donAIC[1])
	selectFrqy[j] <- sum(yuyauAIC[2] < yuyauAIC[1])/length(yuyauAIC[1])
}

L <- c("Proposed cAIC", 
       "Marginal AIC", 
       "Donohue's cAIC", 
       "YuYau's AIC")
       
df105 <- data.frame(x        = rep(a, 4), 
                    val      = c(selectFrqc, 
                                 selectFrqm, 
                                 selectFrqd, 
                                 selectFrqy), 
                    Variable = rep(L, each = length(a)), 
                    m        = 10, 
                    n_i      = 5)
				   				   
G <- paste("1010/AIC_Tabelle_NoCluster_10_NoSize_10_sigma2_", a, 
           "_Int_0.1_Slope_0.2.txt", sep = "")

for (j in 1:length(G)){
	asd <- read.table(G[j], header = TRUE)
	analyAIC <- na.omit(asd[, c(r, 4)])
	margAIC  <- na.omit(asd[, c(7, 5)])
	donAIC   <- na.omit(asd[, c(7, 6)])
	yuyauAIC <- na.omit(asd[, c(7, 3)])
	selectFrqc[j] <- sum(analyAIC[2] < analyAIC[1])/length(analyAIC[1])
	selectFrqm[j] <- sum(margAIC[2]  < margAIC[1]) /length(margAIC[1])
	selectFrqd[j] <- sum(donAIC[2]   < donAIC[1])  /length(donAIC[1])
	selectFrqy[j] <- sum(yuyauAIC[2] < yuyauAIC[1])/length(yuyauAIC[1])
}

L <- c("Proposed cAIC", 
       "Marginal AIC", 
       "Donohue's cAIC", 
       "YuYau's AIC")
df1010 <- data.frame(x        = rep(a, 4), 
                     val      = c(selectFrqc, 
                                  selectFrqm,
                                  selectFrqd, 
                                  selectFrqy), 
                     Variable = rep(L, each = length(a)), 
                     m        = 10, 
                     n_i      = 10)
				   
df0 <- rbind(df55, df510, df105, df1010)

# Levels:
df0$m           <- factor(df0$m, levels = c("5", "10"))
levels(df0$m)   <- c("m==5", "m==10")
df0$n_i         <- factor(df0$n_i, levels = c("5", "10"))
levels(df0$n_i) <- c("n[i]==5", "n[i]==10")

# The plot:

ggplot(data = df0, aes(x = x, y = val,size = 1.2)) + 
  geom_line(aes(color = Variable), size = 1.2) + 
  xlab(expression(tau^2)) + 
  ylab("") + 
  facet_grid(m ~ n_i, labeller = label_parsed) +
 theme(legend.text  = element_text(size = 16)) + 
 theme(legend.title = element_text(size = 16)) + 
 theme(strip.text   = element_text(size = 17)) + 
 theme(axis.text.x  = element_text(size = 14)) + 
 theme(axis.text.x  = element_text(size = 14)) + 
 theme(axis.title.x = element_text(size = 22))
